/pidgin/main: 9f6d0e63e80a: Get rid of some IMHtml traces

Tomasz Wasilczyk twasilczyk at pidgin.im
Sat Feb 1 20:00:40 EST 2014


Changeset: 9f6d0e63e80a98e86ff621154020cbed7ec01fab
Author:	 Tomasz Wasilczyk <twasilczyk at pidgin.im>
Date:	 2014-02-02 02:00 +0100
Branch:	 default
URL: https://hg.pidgin.im/pidgin/main/rev/9f6d0e63e80a

Description:

Get rid of some IMHtml traces

diffstat:

 pidgin/gtkconv.c    |   2 +-
 pidgin/gtksmiley.c  |  10 +++++-----
 pidgin/gtkwebview.c |   4 +++-
 3 files changed, 9 insertions(+), 7 deletions(-)

diffs (71 lines):

diff --git a/pidgin/gtkconv.c b/pidgin/gtkconv.c
--- a/pidgin/gtkconv.c
+++ b/pidgin/gtkconv.c
@@ -2445,7 +2445,7 @@ pidgin_conv_switch_active_conversation(P
 	{
 		/* This is done in default_formatize, which is called from clear_formatting_cb,
 		 * which is (obviously) a clear_formatting signal handler.  However, if we're
-		 * here, we didn't call gtk_imhtml_clear_formatting() (because we want to
+		 * here, we didn't call gtk_webview_clear_formatting() (because we want to
 		 * preserve the formatting exactly as it is), so we have to do this now. */
 		gtk_webview_set_whole_buffer_formatting_only(entry,
 			(features & PURPLE_CONNECTION_FLAG_FORMATTING_WBFO));
diff --git a/pidgin/gtkwebview.c b/pidgin/gtkwebview.c
--- a/pidgin/gtkwebview.c
+++ b/pidgin/gtkwebview.c
@@ -293,7 +293,7 @@ gtk_smiley_tree_lookup(GtkSmileyTree *tr
 		else if (*x == '<') /* Because we're all WYSIWYG now, a '<' char should
 		                     * only appear as the start of a tag.  Perhaps a
 		                     * safer (but costlier) check would be to call
-		                     * gtk_imhtml_is_tag on it */
+		                     * gtk_webview_is_tag on it */
 			break;
 		else {
 			alen = 1;
@@ -507,10 +507,12 @@ gtk_custom_smiley_closed(GdkPixbufLoader
 
 			wids = gtk_text_child_anchor_get_widgets(anchor);
 
+#if 0
 			g_object_set_data_full(G_OBJECT(anchor), "gtkimhtml_plaintext",
 			                       purple_unescape_html(smiley->smile), g_free);
 			g_object_set_data_full(G_OBJECT(anchor), "gtkimhtml_htmltext",
 			                       g_strdup(smiley->smile), g_free);
+#endif
 
 			if (smiley->webview) {
 				if (wids) {



More information about the Commits mailing list
diff --git a/pidgin/gtksmiley.c b/pidgin/gtksmiley.c
--- a/pidgin/gtksmiley.c
+++ b/pidgin/gtksmiley.c
@@ -90,8 +90,8 @@ pidgin_smiley_destroy(PidginSmiley *smil
 /******************************************************************************
  * GtkWebViewSmileys stuff
  *****************************************************************************/
-/* Perhaps these should be in gtkimhtml.c instead. -- sadrul */
-static void add_gtkimhtml_to_list(GtkWebViewSmiley *gtksmiley)
+/* Perhaps these should be in gtkwebview.c instead. -- sadrul */
+static void add_gtkwebview_to_list(GtkWebViewSmiley *gtksmiley)
 {
 	gtk_smileys = g_slist_prepend(gtk_smileys, gtksmiley);
 
@@ -128,7 +128,7 @@ image_changed_cb(PurpleSmiley *smiley, g
 #endif
 }
 
-static GtkWebViewSmiley *smiley_purple_to_gtkimhtml(PurpleSmiley *smiley)
+static GtkWebViewSmiley *smiley_purple_to_gtkwebview(PurpleSmiley *smiley)
 {
 	GtkWebViewSmiley *gtksmiley;
 	gchar *filename;
@@ -188,8 +188,8 @@ void pidgin_smiley_add_to_list(PurpleSmi
 {
 	GtkWebViewSmiley *gtksmiley;
 
-	gtksmiley = smiley_purple_to_gtkimhtml(smiley);
-	add_gtkimhtml_to_list(gtksmiley);
+	gtksmiley = smiley_purple_to_gtkwebview(smiley);
+	add_gtkwebview_to_list(gtksmiley);
 	g_signal_connect(G_OBJECT(smiley), "destroy", G_CALLBACK(pidgin_smiley_del_from_list), NULL);
 }
 